==> blesta-5.10.2.zip: blesta/language/cs_cz/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Dávkový proces';
$lang['AdminBilling.batch.field_passphrase'] = 'Fráze';
$lang['AdminBilling.batch.text_description'] = 'Zadáním přístupového hesla můžete ručně hromadně zpracovat všechny faktury naplánované k automatickému inkasu s lokálně uloženým platebním účtem.';
$lang['AdminBilling.batch.no_passphrase'] = 'Ruční dávkové zpracování není povoleno.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Dávka';
$lang['AdminBilling.batch.page_title'] = 'Fakturační dávka';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Značka s potiskem';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Tisk';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Datum odeslání';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Datum splatnosti';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Datum vyúčtování';
$lang['AdminBilling.printqueue.heading_due'] = 'Due';
$lang['AdminBilling.printqueue.heading_paid'] = 'Placené';
$lang['AdminBilling.printqueue.heading_amount'] = 'Částka';
$lang['AdminBilling.printqueue.heading_client'] = 'Klient #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Ve frontě na tisk nejsou žádné faktury.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Neexistují žádné dříve vytištěné faktury.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Tisková fronta';
$lang['AdminBilling.printqueue.category_printed'] = 'Dříve vytištěné';
$lang['AdminBilling.printqueue.category_to_print'] = 'Tisk';
$lang['AdminBilling.printqueue.page_title'] = 'Fronta tisku vyúčtování';
$lang['AdminBilling.invoices.text_edit'] = 'Upravit';
$lang['AdminBilling.invoices.applied_no_results'] = 'Na tuto fakturu nebyly uplatněny žádné transakce.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Možnosti';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Applied On';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Aplikované';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Částka';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Typ platby';
$lang['AdminBilling.transactions.applied_no_results'] = 'Tato transakce nebyla použita na žádné faktury.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Applied On';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Částka';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Faktura';
$lang['AdminBilling.transactions.no_results'] = 'Neexistují žádné transakce s tímto stavem.';
$lang['AdminBilling.transactions.option_edit'] = 'Upravit';
$lang['AdminBilling.transactions.category_returned'] = 'Vrácené';
$lang['AdminBilling.transactions.category_refunded'] = 'Vrácené prostředky';
$lang['AdminBilling.transactions.category_pending'] = 'Čeká se na';
$lang['AdminBilling.transactions.category_error'] = 'Chyba';
$lang['AdminBilling.transactions.category_voided'] = 'Zrušená platnost';
$lang['AdminBilling.transactions.category_declined'] = 'Odmítnuto';
$lang['AdminBilling.transactions.category_approved'] = 'Schváleno';
$lang['AdminBilling.transactions.heading_options'] = 'Možnosti';
$lang['AdminBilling.transactions.heading_date'] = 'Datum';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Odkaz #';
$lang['AdminBilling.transactions.heading_number'] = 'Číslo';
$lang['AdminBilling.transactions.heading_applied'] = 'Aplikované';
$lang['AdminBilling.transactions.heading_credit'] = 'Připsáno na';
$lang['AdminBilling.transactions.heading_amount'] = 'Částka';
$lang['AdminBilling.transactions.heading_type'] = 'Typ';
$lang['AdminBilling.transactions.heading_client'] = 'Klient #';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transakce';
$lang['AdminBilling.transactions.page_title'] = 'Fakturační transakce';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Důvod zrušení: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Tato služba neobsahuje žádné podrobnosti.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Odeslat';
$lang['AdminBilling.services.action.field_client'] = 'Klient:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push to Client';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Nezrušujte';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Konkrétní datum';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Konec funkčního období';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Zrušení plánu';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Neexistují žádné služby s tímto statusem.';
$lang['AdminBilling.services.text_never'] = 'Nikdy';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Plánované';
$lang['AdminBilling.services.category_in_review'] = 'V přehledu';
$lang['AdminBilling.services.category_pending'] = 'Čeká se na';
$lang['AdminBilling.services.category_suspended'] = 'Pozastaveno';
$lang['AdminBilling.services.category_canceled'] = 'Zrušeno';
$lang['AdminBilling.services.category_active'] = 'Aktivní';
$lang['AdminBilling.services.confirm_delete'] = 'Opravdu chcete tuto službu odstranit?';
$lang['AdminBilling.services.option_delete'] = 'Odstranit';
$lang['AdminBilling.services.option_manage'] = 'Správa';
$lang['AdminBilling.services.heading_options'] = 'Možnosti';
$lang['AdminBilling.services.heading_datecanceled'] = 'Datum zrušení';
$lang['AdminBilling.services.heading_datesuspended'] = 'Datum pozastavení';
$lang['AdminBilling.services.heading_daterenews'] = 'Datum obnovení';
$lang['AdminBilling.services.heading_dateadded'] = 'Datum přidání';
$lang['AdminBilling.services.heading_term'] = 'Termín';
$lang['AdminBilling.services.heading_label'] = 'Štítek';
$lang['AdminBilling.services.heading_package'] = 'Balíček';
$lang['AdminBilling.services.heading_client'] = 'Klient #';
$lang['AdminBilling.services.boxtitle_services'] = 'Služby';
$lang['AdminBilling.services.page_title'] = 'Fakturační služby';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'K této nabídce nejsou přiřazeny žádné faktury.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Zobrazit';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Možnosti';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Datum vyúčtování';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Placené';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Částka';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Faktura #';
$lang['AdminBilling.quotations.no_results'] = 'Neexistují žádné nabídky s tímto stavem.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Jste si jisti, že chcete tuto citaci schválit?';
$lang['AdminBilling.quotations.option_approve'] = 'Schválit';
$lang['AdminBilling.quotations.option_invoice'] = 'Vytvořit fakturu';
$lang['AdminBilling.quotations.option_view'] = 'Zobrazit';
$lang['AdminBilling.quotations.option_edit'] = 'Upravit';
$lang['AdminBilling.quotations.heading_options'] = 'Možnosti';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Datum vypršení platnosti';
$lang['AdminBilling.quotations.heading_date_created'] = 'Datum vytvoření';
$lang['AdminBilling.quotations.heading_total'] = 'Částka';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Mezisoučet';
$lang['AdminBilling.quotations.heading_staff'] = 'Citováno podle';
$lang['AdminBilling.quotations.heading_title'] = 'Název';
$lang['AdminBilling.quotations.heading_client'] = 'Klient #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citace #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citáty';
$lang['AdminBilling.quotations.page_title'] = 'Fakturační citace';
$lang['AdminBilling.invoices.no_results'] = 'Neexistují žádné faktury s tímto stavem.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s krát';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s let';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s měsíců';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s týdnů';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dní';
$lang['AdminBilling.invoices.term_year'] = '%1$s rok';
$lang['AdminBilling.invoices.term_month'] = '%1$s měsíc';
$lang['AdminBilling.invoices.term_week'] = '%1$s týden';
$lang['AdminBilling.invoices.term_day'] = '%1$s den';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s + daň';
$lang['AdminBilling.invoices.option_pay'] = 'Platit';
$lang['AdminBilling.invoices.option_view'] = 'Zobrazit';
$lang['AdminBilling.invoices.option_edit'] = 'Upravit';
$lang['AdminBilling.invoices.category_recurring'] = 'Opakující se';
$lang['AdminBilling.invoices.category_pending'] = 'Čeká se na';
$lang['AdminBilling.invoices.category_pastdue'] = 'Po splatnosti';
$lang['AdminBilling.invoices.category_voided'] = 'Zrušená platnost';
$lang['AdminBilling.invoices.category_closed'] = 'Uzavřeno';
$lang['AdminBilling.invoices.category_drafts'] = 'Návrhy';
$lang['AdminBilling.invoices.category_open'] = 'Otevřít';
$lang['AdminBilling.invoices.heading_count'] = 'Hrabě';
$lang['AdminBilling.invoices.heading_duration'] = 'Doba trvání';
$lang['AdminBilling.invoices.heading_term'] = 'Termín';
$lang['AdminBilling.invoices.heading_options'] = 'Možnosti';
$lang['AdminBilling.invoices.heading_datedue'] = 'Datum splatnosti';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Datum vyúčtování';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Datum uzavření';
$lang['AdminBilling.invoices.heading_due'] = 'Due';
$lang['AdminBilling.invoices.heading_paid'] = 'Placené';
$lang['AdminBilling.invoices.heading_amount'] = 'Částka';
$lang['AdminBilling.invoices.heading_client'] = 'Klient #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Opakující se #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Faktury';
$lang['AdminBilling.invoices.page_title'] = 'Fakturace faktur';
$lang['AdminBilling.managewidgets.text_author'] = 'Autor: Mgr:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Přetažením widgetů zprava doleva je přidáte do přehledu vyúčtování nebo zleva doprava je odeberete.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Chcete-li si přizpůsobit přehled vyúčtování, vyberte si níže uvedené rozložení.';
$lang['AdminBilling.index.action_batch'] = 'Položky čekající na dávku';
$lang['AdminBilling.index.action_printqueue'] = 'Položky čekající na vytištění';
$lang['AdminBilling.index.no_actions'] = 'Žádné nevyřízené akční body.';
$lang['AdminBilling.index.heading_actions'] = 'Akční body';
$lang['AdminBilling.index.customize_dashboard'] = 'Přizpůsobit přehled';
$lang['AdminBilling.index.manage_widgets'] = 'Správa widgetů';
$lang['AdminBilling.index.page_title'] = 'Přehled účtování';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'Plánované datum zrušení nesmí být v minulosti.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Zadaná přístupová fráze je neplatná.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Nebyly vybrány žádné faktury.';
$lang['AdminBilling.!success.services_pushed'] = 'Vybrané služby byly úspěšně přesunuty do nového klienta.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'U vybraných služeb již není plánováno jejich zrušení.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Vybrané služby byly úspěšně naplánovány ke zrušení.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'Vybrané faktury byly označeny jako vytištěné.';

==> blesta-5.11.4.zip: blesta/language/cs_cz/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Dávkový proces';
$lang['AdminBilling.batch.field_passphrase'] = 'Fráze';
$lang['AdminBilling.batch.text_description'] = 'Zadáním přístupového hesla můžete ručně hromadně zpracovat všechny faktury naplánované k automatickému inkasu s lokálně uloženým platebním účtem.';
$lang['AdminBilling.batch.no_passphrase'] = 'Ruční dávkové zpracování není povoleno.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Dávka';
$lang['AdminBilling.batch.page_title'] = 'Fakturační dávka';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Značka s potiskem';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Tisk';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Datum odeslání';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Datum splatnosti';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Datum vyúčtování';
$lang['AdminBilling.printqueue.heading_due'] = 'Due';
$lang['AdminBilling.printqueue.heading_paid'] = 'Placené';
$lang['AdminBilling.printqueue.heading_amount'] = 'Částka';
$lang['AdminBilling.printqueue.heading_client'] = 'Klient #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Ve frontě na tisk nejsou žádné faktury.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Neexistují žádné dříve vytištěné faktury.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Tisková fronta';
$lang['AdminBilling.printqueue.category_printed'] = 'Dříve vytištěné';
$lang['AdminBilling.printqueue.category_to_print'] = 'Tisk';
$lang['AdminBilling.printqueue.page_title'] = 'Fronta tisku vyúčtování';
$lang['AdminBilling.invoices.text_edit'] = 'Upravit';
$lang['AdminBilling.invoices.applied_no_results'] = 'Na tuto fakturu nebyly uplatněny žádné transakce.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Možnosti';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Applied On';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Aplikované';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Částka';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Typ platby';
$lang['AdminBilling.transactions.applied_no_results'] = 'Tato transakce nebyla použita na žádné faktury.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Applied On';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Částka';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Faktura';
$lang['AdminBilling.transactions.no_results'] = 'Neexistují žádné transakce s tímto stavem.';
$lang['AdminBilling.transactions.option_edit'] = 'Upravit';
$lang['AdminBilling.transactions.category_returned'] = 'Vrácené';
$lang['AdminBilling.transactions.category_refunded'] = 'Vrácené prostředky';
$lang['AdminBilling.transactions.category_pending'] = 'Čeká se na';
$lang['AdminBilling.transactions.category_error'] = 'Chyba';
$lang['AdminBilling.transactions.category_voided'] = 'Zrušená platnost';
$lang['AdminBilling.transactions.category_declined'] = 'Odmítnuto';
$lang['AdminBilling.transactions.category_approved'] = 'Schváleno';
$lang['AdminBilling.transactions.heading_options'] = 'Možnosti';
$lang['AdminBilling.transactions.heading_date'] = 'Datum';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Odkaz #';
$lang['AdminBilling.transactions.heading_number'] = 'Číslo';
$lang['AdminBilling.transactions.heading_applied'] = 'Aplikované';
$lang['AdminBilling.transactions.heading_credit'] = 'Připsáno na';
$lang['AdminBilling.transactions.heading_amount'] = 'Částka';
$lang['AdminBilling.transactions.heading_type'] = 'Typ';
$lang['AdminBilling.transactions.heading_client'] = 'Klient #';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transakce';
$lang['AdminBilling.transactions.page_title'] = 'Fakturační transakce';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Důvod zrušení: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Tato služba neobsahuje žádné podrobnosti.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Odeslat';
$lang['AdminBilling.services.action.field_client'] = 'Klient:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push to Client';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Nezrušujte';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Konkrétní datum';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Konec funkčního období';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Zrušení plánu';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Neexistují žádné služby s tímto statusem.';
$lang['AdminBilling.services.text_never'] = 'Nikdy';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Plánované';
$lang['AdminBilling.services.category_in_review'] = 'V přehledu';
$lang['AdminBilling.services.category_pending'] = 'Čeká se na';
$lang['AdminBilling.services.category_suspended'] = 'Pozastaveno';
$lang['AdminBilling.services.category_canceled'] = 'Zrušeno';
$lang['AdminBilling.services.category_active'] = 'Aktivní';
$lang['AdminBilling.services.confirm_delete'] = 'Opravdu chcete tuto službu odstranit?';
$lang['AdminBilling.services.option_delete'] = 'Odstranit';
$lang['AdminBilling.services.option_manage'] = 'Správa';
$lang['AdminBilling.services.heading_options'] = 'Možnosti';
$lang['AdminBilling.services.heading_datecanceled'] = 'Datum zrušení';
$lang['AdminBilling.services.heading_datesuspended'] = 'Datum pozastavení';
$lang['AdminBilling.services.heading_daterenews'] = 'Datum obnovení';
$lang['AdminBilling.services.heading_dateadded'] = 'Datum přidání';
$lang['AdminBilling.services.heading_term'] = 'Termín';
$lang['AdminBilling.services.heading_label'] = 'Štítek';
$lang['AdminBilling.services.heading_package'] = 'Balíček';
$lang['AdminBilling.services.heading_client'] = 'Klient #';
$lang['AdminBilling.services.boxtitle_services'] = 'Služby';
$lang['AdminBilling.services.page_title'] = 'Fakturační služby';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'K této nabídce nejsou přiřazeny žádné faktury.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Zobrazit';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Možnosti';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Datum vyúčtování';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Placené';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Částka';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Faktura #';
$lang['AdminBilling.quotations.no_results'] = 'Neexistují žádné nabídky s tímto stavem.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Jste si jisti, že chcete tuto citaci schválit?';
$lang['AdminBilling.quotations.option_approve'] = 'Schválit';
$lang['AdminBilling.quotations.option_invoice'] = 'Vytvořit fakturu';
$lang['AdminBilling.quotations.option_view'] = 'Zobrazit';
$lang['AdminBilling.quotations.option_edit'] = 'Upravit';
$lang['AdminBilling.quotations.heading_options'] = 'Možnosti';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Datum vypršení platnosti';
$lang['AdminBilling.quotations.heading_date_created'] = 'Datum vytvoření';
$lang['AdminBilling.quotations.heading_total'] = 'Částka';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Mezisoučet';
$lang['AdminBilling.quotations.heading_staff'] = 'Citováno podle';
$lang['AdminBilling.quotations.heading_title'] = 'Název';
$lang['AdminBilling.quotations.heading_client'] = 'Klient #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citace #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citáty';
$lang['AdminBilling.quotations.page_title'] = 'Fakturační citace';
$lang['AdminBilling.invoices.no_results'] = 'Neexistují žádné faktury s tímto stavem.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s krát';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s let';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s měsíců';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s týdnů';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dní';
$lang['AdminBilling.invoices.term_year'] = '%1$s rok';
$lang['AdminBilling.invoices.term_month'] = '%1$s měsíc';
$lang['AdminBilling.invoices.term_week'] = '%1$s týden';
$lang['AdminBilling.invoices.term_day'] = '%1$s den';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s + daň';
$lang['AdminBilling.invoices.option_pay'] = 'Platit';
$lang['AdminBilling.invoices.option_view'] = 'Zobrazit';
$lang['AdminBilling.invoices.option_edit'] = 'Upravit';
$lang['AdminBilling.invoices.category_recurring'] = 'Opakující se';
$lang['AdminBilling.invoices.category_pending'] = 'Čeká se na';
$lang['AdminBilling.invoices.category_pastdue'] = 'Po splatnosti';
$lang['AdminBilling.invoices.category_voided'] = 'Zrušená platnost';
$lang['AdminBilling.invoices.category_closed'] = 'Uzavřeno';
$lang['AdminBilling.invoices.category_drafts'] = 'Návrhy';
$lang['AdminBilling.invoices.category_open'] = 'Otevřít';
$lang['AdminBilling.invoices.heading_count'] = 'Hrabě';
$lang['AdminBilling.invoices.heading_duration'] = 'Doba trvání';
$lang['AdminBilling.invoices.heading_term'] = 'Termín';
$lang['AdminBilling.invoices.heading_options'] = 'Možnosti';
$lang['AdminBilling.invoices.heading_datedue'] = 'Datum splatnosti';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Datum vyúčtování';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Datum uzavření';
$lang['AdminBilling.invoices.heading_due'] = 'Due';
$lang['AdminBilling.invoices.heading_paid'] = 'Placené';
$lang['AdminBilling.invoices.heading_amount'] = 'Částka';
$lang['AdminBilling.invoices.heading_client'] = 'Klient #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Opakující se #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Faktury';
$lang['AdminBilling.invoices.page_title'] = 'Fakturace faktur';
$lang['AdminBilling.managewidgets.text_author'] = 'Autor: Mgr:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Přetažením widgetů zprava doleva je přidáte do přehledu vyúčtování nebo zleva doprava je odeberete.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Chcete-li si přizpůsobit přehled vyúčtování, vyberte si níže uvedené rozložení.';
$lang['AdminBilling.index.action_batch'] = 'Položky čekající na dávku';
$lang['AdminBilling.index.action_printqueue'] = 'Položky čekající na vytištění';
$lang['AdminBilling.index.no_actions'] = 'Žádné nevyřízené akční body.';
$lang['AdminBilling.index.heading_actions'] = 'Akční body';
$lang['AdminBilling.index.customize_dashboard'] = 'Přizpůsobit přehled';
$lang['AdminBilling.index.manage_widgets'] = 'Správa widgetů';
$lang['AdminBilling.index.page_title'] = 'Přehled účtování';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'Plánované datum zrušení nesmí být v minulosti.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Zadaná přístupová fráze je neplatná.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Nebyly vybrány žádné faktury.';
$lang['AdminBilling.!success.services_pushed'] = 'Vybrané služby byly úspěšně přesunuty do nového klienta.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'U vybraných služeb již není plánováno jejich zrušení.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Vybrané služby byly úspěšně naplánovány ke zrušení.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'Vybrané faktury byly označeny jako vytištěné.';
$lang['AdminBilling.services.action.field_suspension_reason'] = 'Důvod pozastavení:';
$lang['AdminBilling.services.action.unsuspend'] = 'Odpojení';
$lang['AdminBilling.services.action.suspend'] = 'Pozastavit';
$lang['AdminBilling.!success.services_unsuspended'] = 'Vybrané služby byly úspěšně odpojeny.';
$lang['AdminBilling.!success.services_suspended'] = 'Vybrané služby byly úspěšně pozastaveny.';
